@@ -37,7 +37,7 @@
  * SUCH DAMAGE.
  *
  *
- * $Id: nfs_prot_openbsd.h,v 1.3.2.7 2005/01/16 23:56:32 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_openbsd.h
  *
  */
 
@@ -58,30 +58,7 @@
 # include <nfs/nfs.h>
 #endif /* HAVE_NFS_NFS_H */
 
-#ifdef HAVE_SYS_MOUNT_H
-# include <net/radix.h>
-# include <sys/socket.h>         /* XXX for AF_MAX */
-/*
- * Get some definitions from sys/mount which would have only gotten included
- * if _KERNEL was defined, but we don't want to define it in am_defs.h
- * globally.
- */
-/* Network address lookup element */
-struct netcred {
-  struct  radix_node netc_rnodes[2];
-  int     netc_exflags;
-  struct  ucred netc_anon;
-};
-
-/* Network export information */
-struct netexport {
-  struct  netcred ne_defexported;               /* Default export */
-  struct  radix_node_head *ne_rtable[AF_MAX+1]; /* Individual exports */
-};
-#endif /* HAVE_SYS_MOUNT_H */
-
 #ifdef	HAVE_UFS_UFS_UFSMOUNT_H
-#if 1
 # ifdef HAVE_UFS_UFS_EXTATTR_H
 /*
  * Need to define _KERNEL to include protected definition of struct
@@ -92,19 +69,14 @@ struct netexport {
 #  include <ufs/ufs/extattr.h>
 #  undef _KERNEL
 # endif /* HAVE_UFS_UFS_EXTATTR_H */
-#endif /* 1 */
 # ifndef MAXQUOTAS
 #  define MAXQUOTAS     2
 # endif /* not MAXQUOTAS */
-#if 0
-#error No longer needed in openbsd3.6
 /*
  * XXX: fake struct nextexport: trying to include proper headers here is too
  * difficult: those headers drag many other headers, etc.
  */
 struct netexport { int this_is_SO_wrong; };
-#endif /* 0 */
-//struct netexport;
 # include <ufs/ufs/ufsmount.h>
 #endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
 
@@ -209,59 +181,6 @@ typedef writeargs nfswriteargs;
 
 # define MOUNT_NFS3 MOUNT_NFS
 # define MNTOPT_NFS3 "nfs"
-# define MOUNTVERS3 ((unsigned long)(3))
-#define	NFS3_FHSIZE 64
-#define FHSIZE3 64		/* size in bytes of a file handle (v3) */
-
-struct nfs_fh3 {
-  u_int fh3_length;
-  union nfs_fh3_u {
-    struct nfs_fh3_i {
-      fhandle_t fh3_i;
-    } nfs_fh3_i;
-    char data[NFS3_FHSIZE];
-  } fh3_u;
-};
-typedef struct nfs_fh3 fhandle3;
-#define fhandle3_len fh3_length
-#define fhandle3_val fh3_u.data
-#if 0
-typedef struct fhandle3 {
-  u_int fhandle3_len;
-  char *fhandle3_val;
-} fhandle3;
-#endif
-
-enum mountstat3 {
-  MNT3_OK = 0,
-  MNT3ERR_PERM = 1,
-  MNT3ERR_NOENT = 2,
-  MNT3ERR_IO = 5,
-  MNT3ERR_ACCES = 13,
-  MNT3ERR_NOTDIR = 20,
-  MNT3ERR_INVAL = 22,
-  MNT3ERR_NAMETOOLONG = 63,
-  MNT3ERR_NOTSUPP = 10004,
-  MNT3ERR_SERVERFAULT = 10006
-};
-typedef enum mountstat3 mountstat3;
-
-struct mountres3_ok {
-  fhandle3 fhandle;
-  struct {
-    u_int auth_flavors_len;
-    int *auth_flavors_val;
-  } auth_flavors;
-};
-typedef struct mountres3_ok mountres3_ok;
-
-struct mountres3 {
-  mountstat3 fhs_status;
-  union {
-    mountres3_ok mountinfo;
-  } mountres3_u;
-};
-typedef struct mountres3 mountres3;
 
 #endif /* NFSMNT_NFSV3 */
 
