@@ -37,7 +37,7 @@
  * SUCH DAMAGE.
  *
  *
- * $Id$
+ * File: am-utils/conf/nfs_prot/nfs_prot_sunos5_8.h
  *
  */
 
@@ -104,10 +104,6 @@
 
 #define AUTOFS_CONFTYPE "ticotsord"
 
-#ifndef INADDR_NONE
-# define INADDR_NONE ((unsigned long) -1)
-#endif /* INADDR_NONE */
-
 /*
  * TYPEDEFS:
  */
