@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mtab.c,v 1.3.2.9 2005/01/03 20:56:15 ezk Exp $
+ * File: am-utils/libamu/mtab.c
  *
  */
 
@@ -125,7 +124,7 @@ hasmnteq(mntent_t *mnt, char *opt)
 {
   if (mnt && opt) {		/* disallow null input pointers */
     if ( *opt ) {		/* disallow the null string as an opt */
-      char *str = hasmntopt(mnt, opt);
+      char *str = amu_hasmntopt(mnt, opt);
       if ( str ) {		/* option was there */
 	char *eq = str + strlen(opt); /* Look at char just after option */
 	if (*eq == '=')		/* Is it '=' ? */
@@ -145,7 +144,7 @@ hasmnteq(mntent_t *mnt, char *opt)
 int
 hasmntval(mntent_t *mnt, char *opt)
 {
-  char *str = hasmntopt(mnt, opt);
+  char *str = amu_hasmntopt(mnt, opt);
 
   if (str) { /* The option was there */
 
